==> ruby-date2-2.1.tgz: lib/ruby/site_ruby/1.6/qholiday.rb <==
# qholiday.rb: Written by Tadayoshi Funaba 1998-2000
# $Id: qholiday.rb,v 1.10 2000-07-16 10:23:53+09 tadf Exp $

class Date

  def qfixed?
    return false unless (2405163..2432752) === jd	# 1873-01-04/1948-07-19
    *x = mon, mday
    (x == [ 1,  3] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [ 1,  5] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [ 1, 29] and (2405163..2405224) === jd) or	# 1873-01-04/1873-03-06
    (x == [ 1, 30] and (2405446..2419648) === jd) or	# 1873-10-14/1912-09-02
    (x == [ 2, 11] and (2405225..2432752) === jd) or	# 1873-03-07/1948-07-19
    (x == [ 4,  3] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [ 4, 29] and (2424943..2432752) === jd) or	# 1927-03-03/1948-07-19
    (x == [ 7, 30] and (2419649..2424942) === jd) or	# 1912-09-03/1927-03-02
    (x == [ 8, 31] and (2419649..2419966) === jd) or	# 1912-09-03/1913-07-17
    (x == [ 9, 17] and (2405446..2407535) === jd) or	# 1873-10-14/1879-07-04
    (x == [10, 17] and (2407536..2432752) === jd) or	# 1879-07-05/1948-07-19
    (x == [10, 31] and (2419967..2424942) === jd) or	# 1913-07-18/1927-03-02
    (x == [11,  3] and (2405163..2419648) === jd) or	# 1873-01-04/1912-09-02
    (x == [11,  3] and (2424943..2432752) === jd) or	# 1927-03-03/1948-07-19
    (x == [11, 23] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [12, 25] and (2424943..2432752) === jd)	# 1927-03-03/1948-07-19
  end

  class << self

    def deq(a, b, y)
      (a + 0.242194 * (y - 1980) - ((y - b) / 4).to_i).to_i
    end

    private :deq

    def veq(y, sg=ITALY)
      case y
      when 1851..1899; a = 19.8277; b = 1983.0
      when 1900..1979; a = 20.8357; b = 1983.0
      when 1980..2099; a = 20.8431; b = 1980.0
      when 2100..2150; a = 21.8510; b = 1980.0
      end
      jd = civil_to_jd(y, 3, deq(a, b, y), sg)
      unless (2397124..2506696) === jd			# 1851-01-01/2150-12-31
	raise ArgumentError, 'domain error'
      end
      return new1(jd, sg)
    end

    def aeq(y, sg=ITALY)
      case y
      when 1851..1899; a = 22.2588; b = 1983.0
      when 1900..1979; a = 23.2588; b = 1983.0
      when 1980..2099; a = 23.2488; b = 1980.0
      when 2100..2150; a = 24.2488; b = 1980.0
      end
      jd = civil_to_jd(y, 9, deq(a, b, y), sg)
      unless (2397124..2506696) === jd			# 1851-01-01/2150-12-31
	raise ArgumentError, 'domain error'
      end
      return new1(jd, sg)
    end

  end

  def veq?
    return false unless (2405163..2432752) === jd	# 1873-01-04/1948-07-19
    self === type.veq(year, sg)
  end

  def aeq?
    return false unless (2405163..2432752) === jd	# 1873-01-04/1948-07-19
    self === type.aeq(year, sg)
  end

  def qnhol?
    qfixed? or
    ((2407141..2432752) === jd and (veq? or aeq?))	# 1878-06-05/1948-07-19
  end

end

==> ruby-date2-2.4.3.tgz: lib/ruby/site_ruby/1.6/qholiday.rb <==
# qholiday.rb: Written by Tadayoshi Funaba 1998-2001
# $Id: qholiday.rb,v 1.12 2001-02-13 01:13:07+09 tadf Exp $

class Date

  def qfixed?
    return false unless (2405163..2432752) === jd	# 1873-01-04/1948-07-19
    *x = mon, mday
    (x == [ 1,  3] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [ 1,  5] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [ 1, 29] and (2405143..2405224) === jd) or	# 1872-12-15/1873-03-06
    (x == [ 1, 30] and (2405446..2419649) === jd) or	# 1873-10-14/1912-09-03
    (x == [ 2, 11] and (2405225..2432752) === jd) or	# 1873-03-07/1948-07-19
    (x == [ 4,  3] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [ 4, 29] and (2424943..2432752) === jd) or	# 1927-03-03/1948-07-19
    (x == [ 7, 30] and (2419650..2424942) === jd) or	# 1912-09-04/1927-03-02
    (x == [ 8, 31] and (2419650..2424942) === jd) or	# 1912-09-04/1927-03-02
    (x == [ 9, 17] and (2405446..2407535) === jd) or	# 1873-10-14/1879-07-04
    (x == [10, 17] and (2407536..2432752) === jd) or	# 1879-07-05/1948-07-19
    (x == [10, 31] and (2419967..2424942) === jd) or	# 1913-07-18/1927-03-02
    (x == [11,  3] and (2405163..2419649) === jd) or	# 1873-01-04/1912-09-03
    (x == [11,  3] and (2424943..2432752) === jd) or	# 1927-03-03/1948-07-19
    (x == [11, 23] and (2405446..2432752) === jd) or	# 1873-10-14/1948-07-19
    (x == [12, 25] and (2424943..2432752) === jd)	# 1927-03-03/1948-07-19
  end

  class << self

    def deq(a, b, y)
      (a + 0.242194 * (y - 1980) - ((y - b) / 4).to_i).to_i
    end

    private :deq

    def qveq(y, sg=ITALY)
      case y
      when 1851..1899; a = 19.8277; b = 1983.0
      when 1900..1979; a = 20.8357; b = 1983.0
      when 1980..2099; a = 20.8431; b = 1980.0
      when 2100..2150; a = 21.8510; b = 1980.0
      end
      jd = civil_to_jd(y, 3, deq(a, b, y), sg)
      unless (2397124..2506696) === jd			# 1851-01-01/2150-12-31
	raise ArgumentError, 'domain error'
      end
      return new1(jd, sg)
    end

    def qaeq(y, sg=ITALY)
      case y
      when 1851..1899; a = 22.2588; b = 1983.0
      when 1900..1979; a = 23.2588; b = 1983.0
      when 1980..2099; a = 23.2488; b = 1980.0
      when 2100..2150; a = 24.2488; b = 1980.0
      end
      jd = civil_to_jd(y, 9, deq(a, b, y), sg)
      unless (2397124..2506696) === jd			# 1851-01-01/2150-12-31
	raise ArgumentError, 'domain error'
      end
      return new1(jd, sg)
    end

  end

  def qveq?
    return false unless (2405163..2432752) === jd	# 1873-01-04/1948-07-19
    self === type.qveq(year, sg)
  end

  def qaeq?
    return false unless (2405163..2432752) === jd	# 1873-01-04/1948-07-19
    self === type.qaeq(year, sg)
  end

  def qnhol?
    qfixed? or
    ((2407141..2432752) === jd and (qveq? or qaeq?))	# 1878-06-05/1948-07-19
  end

end
